@@ -246,6 +246,8 @@ menuText L OptionsFontsRegular "Vakinainen" 0 {Muuta yleiskirjaisintyyppi}
 menuText L OptionsFontsMenu "Valikko" 0 {Vaihda valikon kirjaisintyyppi}
 menuText L OptionsFontsSmall "Pieni" 0 {Muuta pieni kirjaisintyyppi}
 menuText L OptionsFontsFixed "Pysyv" 0 {Muuta vakiolevyinen kirjaisintyyppi}
+# ====== TODO To be translated ======
+menuText L OptionsEvalbar "Score Bar" 0 {Score bar options}
 menuText L OptionsGInfo "Pelin tiedot" 0 {Pelitietojen vaihtoehdot}
 menuText L OptionsFics "FICS" 0 {Free Chess Internet Server}
 menuText L OptionsFicsAuto "Korota automaattisesti kuningattareksi" 0
@@ -258,6 +260,20 @@ menuText L OptionsFicsCommands "Alusta kskyt" 0
 menuText L OptionsFicsNoRes "Ei tuloksia" 0
 menuText L OptionsFicsNoReq "Ei pyyntj" 0
 menuText L OptionsFicsPremove "Salli etukteissiirto" 0
+# ====== TODO To be translated ======
+menuText L OptionsEvalMain "Main Board" 0
+# ====== TODO To be translated ======
+menuText L OptionsEvalBrowser "Game Browsers" 0
+# ====== TODO To be translated ======
+menuText L OptionsEvalFics "Fics boards" 0
+# ====== TODO To be translated ======
+menuText L OptionsEvalTime "Evaluation time" 0 {Time for quick analysis probe}
+# ====== TODO To be translated ======
+menuText L OptionsEvalScale "Scale" 0 {Scorebar scale}
+# ====== TODO To be translated ======
+menuText L OptionsEvalTicks "Show ticks" 0
+# ====== TODO To be translated ======
+menuText L OptionsEvalLog  "Logarithmic Eval" 0
 
 menuText L OptionsLanguage "Kieli" 0 {Valitse valikon kieli}
 menuText L OptionsMovesTranslatePieces "Knn nappulat" 0 {Knn nappuloiden ensimminen kirjain}
@@ -346,6 +362,8 @@ menuText L GInfoToolBar "Tykalurivi"  0
 menuText L GInfoButtonBar "Painikerivi"  0
 # TODO
 menuText L GInfoStatusBar "Status Bar"  0
+# ====== TODO To be translated ======
+menuText L GInfoEvalBar "Score Bar" 0
 
 translate L FlipBoard {Knn lauta}
 translate L RaiseWindows {Nosta ikkunat}
