@@ -41,8 +41,7 @@ menuText F Edit "diter" 0
 menuText F EditAdd "Ajouter variante" 0 {Ajouter une variante}
 menuText F EditPasteVar "Coller variante" 0
 menuText F EditDelete "Effacer variante" 0 {Effacer cette variante}
-# ====== TODO To be translated ======
-menuText F EditDeleteComment "Delete Comment" 0
+menuText F EditDeleteComment "Effacer les commentaires" 0
 menuText F EditFirst "Dplacer en tte" 0 \
   {Dplacer cette variante en tte de liste}
 menuText F EditMain "Variante vers ligne principale" 13 \
@@ -166,8 +165,7 @@ menuText F ToolsBookTuning "Config. bibliothque" 0 {Configuration fine d'une bib
 menuText F ToolsMaint "Maintenance" 0 {Maintenance de la base}
 menuText F ToolsMaintWin "Fentre de maintenance" 0 \
   {Ouvrir/Fermer la fentre de maintenance}
-# ====== TODO To be translated ======
-menuText F ToolsMaintExtra "Extra Tags" 0 {Extra Tags}
+menuText F ToolsMaintExtra "Marqueur supplmentaire" 0 {Extra Tags}
 menuText F ToolsMaintCompact "Compacter la base..." 0 \
   {Compacter la base: supprimer les parties effaces et les noms non utiliss}
 menuText F ToolsMaintClass "Classer les parties suivant ECO" 2 \
@@ -186,7 +184,6 @@ menuText F ToolsMaintNameSite "Corriger les noms de lieux.." 21 \
   {Vrifier l'orthographe des noms de lieux}
 menuText F ToolsMaintNameRound "Corriger les noms des rondes..." 22 \
   {Vrifier l'orthographe des noms de rondes}
-# ====== TODO To be translated ======
 menuText F ToolsMaintFixBase "Rparer base" 0 {Essaie de rparer une base corrompue}
 menuText F ToolsConnectHardware "Brancher hardware" 0 {Brancher hardware extrieur}
 menuText F ToolsConnectHardwareConfigure "Configurer..." 0 {Configurer la connexion au hardware extrieur}
@@ -249,8 +246,7 @@ menuText F Options "Options" 0
 menuText F OptionsBoard "Echiquier" 0 {Options d'aspect de l'chiquier}
 menuText F OptionsColour "Couleurs" 0 {Default text widget color}
 menuText F OptionsBackColour "Arrire-plan" 0 {Default text widget color}
-# ====== TODO To be translated ======
-menuText F OptionsBackColourGlobal "Global" 0 {Global background color}
+menuText F OptionsBackColourGlobal "Couleur de fond" 0 {Global background color}
 menuText F OptionsMainLineColour "Flche coup principal" 0 {Mainline arrows}
 menuText F OptionsVarLineColour "Flche coup variante" 0 {Variation arrows}
 menuText F OptionsEngineLineColour "Flche moteur" 0 {Flche moteur}
@@ -267,6 +263,7 @@ menuText F OptionsFontsRegular "Normales" 0 {Changer les polices normales}
 menuText F OptionsFontsMenu "Menu" 0 {Changer la police des menus}
 menuText F OptionsFontsSmall "Petites" 0 {Changer les petites polices}
 menuText F OptionsFontsFixed "Fixe" 0 {Changer les polices de chasse fixe}
+menuText F OptionsEvalbar "Options de la barre de score" 0 {Score bar options}
 menuText F OptionsGInfo "Informations de la partie" 7 {Options d'information de la partie}
 menuText F OptionsFics "FICS" 0
 menuText F OptionsFicsAuto "Autopromote Reine" 0
@@ -278,7 +275,16 @@ menuText F OptionsFicsCommands "Script d'initialisation" 0
 menuText F OptionsFicsNoRes "Sans rsultats" 0
 menuText F OptionsFicsNoReq "Sans requtes" 0
 menuText F OptionsFicsPremove "Pr-move accept" 0
-menuText F OptionsLanguage "Langue" 0 {Slectionner le menu de choix des langues}
+menuText F OptionsEvalMain "Echiquier principale" 0
+menuText F OptionsEvalBrowser "Explorateur de parties" 0
+menuText F OptionsEvalFics "Echiquier FICS" 0
+menuText F OptionsEvalTime "Temps d'valuation" 0 {Time for quick analysis probe}
+# ====== TODO To be translated ======
+menuText F OptionsEvalScale "Scale" 0 {Scorebar scale}
+# ====== TODO To be translated ======
+menuText F OptionsEvalTicks "Show ticks" 0
+menuText F OptionsEvalLog  "Evaluation logarithmique" 0
+menuText F OptionsLanguage "Langues" 0 {Slectionner le menu de choix des langues}
 menuText F OptionsMovesTranslatePieces "Traduction des pices" 0 {Convertit la premire lettre des pices}
 menuText F OptionsMovesHighlightLastMove "Surbrillance dernier coup" 0 {Surbrillance du dernier coup}
 menuText F OptionsMovesHighlightLastMoveDisplay "Afficher" 0 {Afficher la surbrillance du dernier coup}
@@ -294,8 +300,7 @@ menuText F OptionsMovesDelay "Dlai entre les coups" 3 \
   {Positionner le dlai entre deux coups en mode automatique}
 menuText F OptionsMovesCoord "Coordonnes entre les coups" 0 \
   {Accepter l'entre des coups par coordonnes ("g1f3")}
-# ====== TODO To be translated ======
-menuText F OptionsMovesSuggest "Show Suggested Moves" 0 {Turn on/off move suggestion}
+menuText F OptionsMovesSuggest "Montrer les coup suggrs" 0 {Turn on/off move suggestion}
 menuText F OptionsShowVarPopup "Montrer fentre des variantes" 0 {Affichage automatique des variantes}  
 menuText F OptionsMovesSpace "Ajouter un espace aprs le numro du coup" 0 {Espace aprs numro du coup}  
 menuText F OptionsMovesKey "Compltion clavier" 0 \
@@ -365,6 +370,7 @@ menuText F GInfoMenuBar "Barre de Menu"  0
 menuText F GInfoToolBar "Barre d'outils"  0
 menuText F GInfoButtonBar "Barre  boutons"  0
 menuText F GInfoStatusBar "Barre d'tat"  0
+menuText F GInfoEvalBar "Barre d'valuation" 0
 translate F FlipBoard {Retourner l'chiquier}
 translate F RaiseWindows {Fentre d'arbitrage}
 translate F AutoPlay {Lecture automatique}
@@ -561,8 +567,7 @@ menuText F TreeOptAutomask "Auto-chargement Mask" 0 "Auto-Load most recent mask
 menuText F TreeOptCacheSize "Taille du cache" 0 {Taille du cache}
 menuText F TreeOptShowBar "Affichage barre de progression" 0 "Show tree progress bar."
 menuText F TreeOptShowFrame "Affichage fentre boutons" 0 "Afficher la fentre de boutons."
-# ====== TODO To be translated ======
-menuText F TreeOptSmallFont "Use Custom Font" 0 "Use font_Small for Gamelist."
+menuText F TreeOptSmallFont "Utiliser polices personalises" 0 "Utiliser petite police pour liste des parties"
 menuText F TreeOptSortBest "Tri des meilleurs jeux" 0 "Tri des meilleurs jeux selon ELO."
 menuText F TreeHelp "Aide" 0
 menuText F TreeHelpTree "Aide Arbre" 0
@@ -587,10 +592,8 @@ translate F RemoveFromMask {Enlever du masque}
 translate F AddThisMoveToMask {Ajouter ce coup au masque}
 translate F SearchMask {Recherche dans masque}
 translate F DisplayMask {Affichage du masque}
-# ====== TODO To be translated ======
-translate F MaskShowMarkers "Show Markers"
-# ====== TODO To be translated ======
-translate F MaskShowToolTips {Show Tooltips}
+translate F MaskShowMarkers "Montrer les marqueurs"
+translate F MaskShowToolTips {Montrer les info-bulles}
 translate F Nag {Code Nag}
 translate F Marker {Marqueur}
 translate F Include {Inclure}
@@ -644,8 +647,7 @@ translate F FinderCtxBackup {Sauvegarder}
 translate F FinderCtxCopy {Copier}
 translate F FinderCtxMove {Dplacer}
 translate F FinderCtxDelete {Supprimer}
-# ====== TODO To be translated ======
-translate F FinderCtxRename {Rename}
+translate F FinderCtxRename {Renommer}
 translate F FinderDirOpen {Ouvrir Rpertoire}
 
 # Player finder:
@@ -658,8 +660,7 @@ menuText F PListSortElo "Elo" 0
 menuText F PListSortGames "Parties" 0
 menuText F PListSortOldest "Les plus vieux" 0
 menuText F PListSortNewest "Les plus rcents" 0
-# ====== TODO To be translated ======
-menuText F PListSortCountry "Country" 0
+menuText F PListSortCountry "Pays" 0
 
 # Tournament finder:
 menuText F TmtFile "Fichier" 0
@@ -686,7 +687,6 @@ menuText F GraphOptions "Options" 0
 menuText F GraphOptionsWhite "Blancs" 0
 menuText F GraphOptionsBlack "Noirs" 0
 menuText F GraphOptionsDots "Montrer les points connus" 0
-# ====== TODO To be translated ======
 menuText F GraphOptionsSpelling "Elo from Spelling File" 0
 menuText F GraphOptionsBar "Surbrillance de la position actuelle" 0
 menuText F GraphOptionsBoth "Les deux" 4
@@ -932,16 +932,11 @@ translate F GlistUndeleteAllGames {Ds-effacer toutes les parties du filtre}
 translate F GlistAlignL {Aligner  gauche}
 translate F GlistAlignR {Aligner  droite}
 translate F GlistAlignC {Centrer}
-# ====== TODO To be translated ======
-translate F GlistMoveFieldUp {Move up}
-# ====== TODO To be translated ======
-translate F GlistMoveFieldDown {Move down}
-# ====== TODO To be translated ======
-translate F GlistMoveFieldFirst {Move to first}
-# ====== TODO To be translated ======
-translate F GlistMoveFieldLast {Move to last}
-# ====== TODO To be translated ======
-translate F GlistMoveFieldN {Move to N}
+translate F GlistMoveFieldUp {Monter}
+translate F GlistMoveFieldDown {Descendre}
+translate F GlistMoveFieldFirst {Passer au premier}
+translate F GlistMoveFieldLast {Passer au dernier}
+translate F GlistMoveFieldN {Passer au N}
 
 # Maintenance window:
 translate F DatabaseName {Nom de base:}
@@ -981,11 +976,9 @@ translate F CompactDatabase {Compacter la base}
 translate F SortDatabase {Trier la base}
 translate F AddEloRatings {Ajouter les classements Elo}
 translate F AutoloadGame {Chargement automatique du numro de partie}
-# ====== TODO To be translated ======
-translate F StripTags {Extra Tags}
+translate F StripTags {Marqueurs supplmentaires}
 translate F StripTag {Enlever les marqueurs}
-# ====== TODO To be translated ======
-translate F AddTag {Add Tag}
+translate F AddTag {Ajouter un marqueurs}
 translate F CheckGames {Vrifier les parties}
 translate F Cleaner {Nettoyer}
 translate F CleanerHelp {
@@ -1306,8 +1299,7 @@ translate F NameEditSelect {Parties  diter}
 translate F NameEditReplace {Remplacer}
 translate F NameEditWith {avec}
 translate F NameEditMatches {Correspondances: Presser Alt+1  Alt+9 pour slectionner}
-# ====== TODO To be translated ======
-translate F MatchPattern {Match Pattern}
+translate F MatchPattern {Positions corespondantes}
 
 # Classify window:
 translate F Classify {Classer}
@@ -1376,10 +1368,8 @@ translate F CopyErrNotOpen {n'est pas ouverte}
 translate F LightSquares {Cases blanches}
 translate F DarkSquares {Cases noires}
 translate F SelectedSquares {Cases slectionnes}
-# ====== TODO To be translated ======
-translate F SelectedOutline {Selected Box}
-# ====== TODO To be translated ======
-translate F SuggestedSquares {Suggested}
+translate F SelectedOutline {Bordure case slectionne}
+translate F SuggestedSquares {Suggres}
 translate F Grid {Grille}
 translate F Previous {Prcdents}
 translate F WhitePieces {Pices blanches}
@@ -1458,8 +1448,7 @@ translate F moveblunderthreshold {le coup est une erreur si les pertes sont supr
 translate F limitanalysis {limiter le temps d'analyse}
 translate F seconds {secondes}
 translate F Abort {Arrter}
-# ====== TODO To be translated ======
-translate F Quit {Quit}
+translate F Quit {Quitter}
 translate F Resume {Reprendre}
 translate F Restart {Recommencer}
 translate F OutOfOpening {Hors de l'ouverture}
