@@ -279,6 +279,8 @@ menuText O OptionsFontsRegular "Vanlig" 0 {Endre den vanlige skrifttypen}
 menuText O OptionsFontsMenu "Meny" 0 {Velg skrifttype i menyer}
 menuText O OptionsFontsSmall "Liten" 0 {Endre den lille skrifttypen}
 menuText O OptionsFontsFixed "Fastbredde" 0 {Endre fastbreddeskrifttypen}
+# ====== TODO To be translated ======
+menuText O OptionsEvalbar "Score Bar" 0 {Score bar options}
 menuText O OptionsGInfo "Partiinformasjon" 0 {Informasjonsinnstillinger}
 menuText O OptionsFics "FICS" 0
 menuText O OptionsFicsAuto "Automatisk dronning" 0
@@ -290,6 +292,20 @@ menuText O OptionsFicsCommands "Oppstartskommandoer" 0
 menuText O OptionsFicsNoRes "Ingen resultater" 0
 menuText O OptionsFicsNoReq "Ingen forespørsler" 0
 menuText O OptionsFicsPremove "Tillat forhåndstrekk" 0
+# ====== TODO To be translated ======
+menuText O OptionsEvalMain "Main Board" 0
+# ====== TODO To be translated ======
+menuText O OptionsEvalBrowser "Game Browsers" 0
+# ====== TODO To be translated ======
+menuText O OptionsEvalFics "Fics boards" 0
+# ====== TODO To be translated ======
+menuText O OptionsEvalTime "Evaluation time" 0 {Time for quick analysis probe}
+# ====== TODO To be translated ======
+menuText O OptionsEvalScale "Scale" 0 {Scorebar scale}
+# ====== TODO To be translated ======
+menuText O OptionsEvalTicks "Show ticks" 0
+# ====== TODO To be translated ======
+menuText O OptionsEvalLog  "Logarithmic Eval" 0
 
 menuText O OptionsLanguage "Språk" 0 {Velg menyspråk}
 menuText O OptionsMovesTranslatePieces "Oversett brikker" 0 {Oversett brikkenes første bokstav}
@@ -375,6 +391,8 @@ menuText O GInfoMenuBar "Menylinje"  0
 menuText O GInfoToolBar "Verktøylinje"  0
 menuText O GInfoButtonBar "Knapperad"  0
 menuText O GInfoStatusBar "Statuslinje"  0
+# ====== TODO To be translated ======
+menuText O GInfoEvalBar "Score Bar" 0
 
 translate O FlipBoard {Snu brettet}
 translate O RaiseWindows {Vinduer til forgrunnen}
