@@ -1,7 +1,7 @@
 # port.tcl:
 # Scid in Portuguese.
 # Translated by G. Silva (martinus at FICS)
-# Last edited 2019-03-24
+# Last edited 2024-09-19
 
 addLanguage U {Portuguese} 0 ;#iso8859-1
 
@@ -38,8 +38,7 @@ menuText U Edit "Editar" 0
 menuText U EditAdd "Adicionar variante" 0 {Adiciona variante da partida}
 menuText U EditPasteVar "Colar variante" 0
 menuText U EditDelete "Apagar variante" 0 {Exclui variante da partida}
-# ====== TODO To be translated ======
-menuText U EditDeleteComment "Delete Comment" 0
+menuText U EditDeleteComment "Apagar comentrio" 0
 menuText U EditFirst "Converte para Primeira Variante" 14 \
   {Faz com que uma variante seja a primeira da lista}
 menuText U EditMain "Converte variante para Linha Principal" 24 \
@@ -158,9 +157,8 @@ menuText U ToolsTrainFics "Jogar na Internet"  0 {Jogar no freechess.org}
 menuText U ToolsBookTuning "Editar o Livro" 0 {Editar o livro de aberturas}
 menuText U ToolsMaint "Manuteno" 0 {Ferramentas de manutencao de bases de dados Scid}
 menuText U ToolsMaintWin "Janela de Manuteno" 0 \
-  {Abre/Fecha a janela de manutencao de bases de dados Scid}
-# ====== TODO To be translated ======
-menuText U ToolsMaintExtra "Extra Tags" 0 {Extra Tags}
+  {Abre/Fecha a janela de manuteno de bases de dados Scid}
+menuText U ToolsMaintExtra "Etiquetas Extra" 0 {Etiquetas Extra}
 menuText U ToolsMaintCompact "Compactar Base..." 0 \
   {Compacta arquivos de bases de dados, removendo jogos deletados e nomes nao utilizados}
 menuText U ToolsMaintClass "Classificar jogos por ECO..." 2 \
@@ -181,8 +179,7 @@ menuText U ToolsMaintNameSite "Verificao Ortogrfica de Lugares..." 11 \
   {Verifica a correcao dos nomes de lugares usando o arquivo de correcao ortografica}
 menuText U ToolsMaintNameRound "Verificao Ortogrfica de Rodadas..." 11 \
   {Verificao dos nomes de rodadas usando o arquivo de correcao ortografica}
-# ====== TODO To be translated ======
-menuText U ToolsMaintFixBase "Reparar a base" 0 {Tenta reparar uma base corrupto}
+menuText U ToolsMaintFixBase "Reparar a base" 0 {Tenta reparar uma base corrompida}
 menuText U ToolsConnectHardware "Ligar Hardware" 0 {Connect external hardware}
 menuText U ToolsConnectHardwareConfigure "Configurar..." 0 {Configure external hardware and connection}
 menuText U ToolsConnectHardwareNovagCitrineConnect "Ligar Novag Citrine" 9 {Connect Novag Citrine with Scid}
@@ -245,25 +242,24 @@ menuText U Options "Opes" 0
 menuText U OptionsBoard "Tabuleiro" 0 {Opes de aparncia do tabuleiro} ;# ***
 menuText U OptionsColour "Cor do Fundo" 0 {Default text widget color}
 menuText U OptionsBackColour "Fundo" 0 {Default text widget color}
-# ====== TODO To be translated ======
-menuText U OptionsBackColourGlobal "Global" 0 {Global background color}
+menuText U OptionsBackColourGlobal "Global" 0 {Cor global para fundo}
 menuText U OptionsMainLineColour "Setas da Linha Principal" 0 {Mainline arrows}
 menuText U OptionsVarLineColour "Setas da Variante" 0 {Variation arrows}
 menuText U OptionsEngineLineColour "Setas do Programa" 0 {Engine arrows}
 menuText U OptionsRowColour "Linhas" 0 {Default tree/book row color}
-# ====== TODO To be translated ======
-menuText U OptionsHighlightColour "Highlight" 0 {Default text highlight color}
+menuText U OptionsHighlightColour "Destaque" 0 {Default text highlight color}
 menuText U OptionsSwitcherColour "Alternador" 0 {Default db switcher color}
 menuText U OptionsProgressColour "Barra de Progresso" 0 {Default progressbar color}
 menuText U OptionsScoreColour "Grfico dos Pontos" 0 {}
 menuText U OptionsScoreBarColour "Grfico de pontos atual" 0 {}
 menuText U OptionsNames "Meus Nomes de Jogador..." 0 {Editar os meus nomes de jogador} ;# ***
 menuText U OptionsExport "Exportao" 0 {Muda as Opes de exportacao de texto}
-menuText U OptionsFonts "Fontes" 0 {Muda os fontes}
+menuText U OptionsFonts "Fontes" 0 {Muda as fontes}
 menuText U OptionsFontsRegular "Normal" 0 {Fonte Normal}
 menuText U OptionsFontsMenu "Menu" 0 {Change the menu font} ;# ***
-menuText U OptionsFontsSmall "Pequeno" 0 {Fonte pequeno}
+menuText U OptionsFontsSmall "Pequeno" 0 {Fonte pequena}
 menuText U OptionsFontsFixed "Fixo" 0 {Fonte de largura fixa}
+menuText U OptionsEvalbar "Barra de avaliao" 0 {Score bar options}
 menuText U OptionsGInfo "Informaes do Jogo" 0 {Opes de informacao do jogo}
 menuText U OptionsFics "FICS" 0
 menuText U OptionsFicsAuto "Promover sempre a Dama" 0
@@ -275,6 +271,15 @@ menuText U OptionsFicsCommands "Comandos de Incio" 0
 menuText U OptionsFicsNoRes "Ocultar Resultados" 0
 menuText U OptionsFicsNoReq "Ocultar Pedidos" 0
 menuText U OptionsFicsPremove "Permitir Movimento Antecipado" 0
+menuText U OptionsEvalMain "Tabuleiro principal" 0
+menuText U OptionsEvalBrowser "Pesquisadores de jogos" 0
+menuText U OptionsEvalFics "Tabuleiros FICS" 0
+menuText U OptionsEvalTime "Tempo de avaliao" 0 {Time for quick analysis probe}
+# ====== TODO To be translated ======
+menuText U OptionsEvalScale "Scale" 0 {Scorebar scale}
+# ====== TODO To be translated ======
+menuText U OptionsEvalTicks "Show ticks" 0
+menuText U OptionsEvalLog  "Avaliao logaritmica" 0
 menuText U OptionsLanguage "Linguagem" 0 {Menu de selecao de linguagem}
 menuText U OptionsMovesTranslatePieces "Traduzir peas" 0 {Traduzir a primeira letra das peas}
 menuText U OptionsMovesHighlightLastMove "Destacar ltimo movimento" 0 {Destaca o ltimo movimento}
@@ -291,8 +296,7 @@ menuText U OptionsMovesDelay "Tempo de atraso p/ Jogo automtico..." 1 \
   {Define o tempo de espera antes de entrar no modo de jogo automatico}
 menuText U OptionsMovesCoord "Entrada de movimentos por coordenadas" 0 \
   {Aceita o estilo de entrada de movimentos por coordenadas ("g1f3")}
-# ====== TODO To be translated ======
-menuText U OptionsMovesSuggest "Show Suggested Moves" 0 {Turn on/off move suggestion}
+menuText U OptionsMovesSuggest "Mostrar lances sugeridos" 0 {Turn on/off move suggestion}
 menuText U OptionsShowVarPopup "Mostrar janela de variantes" 0 {Turn on/off the display of a variations window}  
 menuText U OptionsMovesSpace "Adicionar um espao depois do nmero do lance" 0 {Add spaces after move number}  
 menuText U OptionsMovesKey "Auto completar" 0 \
@@ -363,6 +367,7 @@ menuText U GInfoMenuBar "Barra do Men"  0
 menuText U GInfoToolBar "Barra de Funes"  0
 menuText U GInfoButtonBar "Barra Inferior"  0
 menuText U GInfoStatusBar "Barra de Estado"  0
+menuText U GInfoEvalBar "Barra de avaliao" 0
 translate U FlipBoard {Rodar Tabuleiro}
 translate U RaiseWindows {Ativar janelas}
 translate U AutoPlay {Jogo automtico}
@@ -465,8 +470,7 @@ translate U readonly {apenas leitura}
 translate U altered {alterado}
 translate U tagsDescript {Etiqueta Extra (eg: Anotador "Anand")}
 translate U prevTags {Usar o anterior}
-# ====== TODO To be translated ======
-translate U value {Value}
+translate U value {Valor}
 
 # Standard error messages:
 translate U ErrNotOpen {Esta base no est aberta.} ;# ***
@@ -567,13 +571,12 @@ menuText U TreeOptAutomask "Abrir mscara automaticamente" 0 "Auto-Load most rece
 menuText U TreeOptCacheSize "Tamanho da Cache" 0 {Define o tamanho do cache}
 menuText U TreeOptShowBar "Mostrar Barra de Progresso" 0 "Mostrar barra de progresso da rvore."
 menuText U TreeOptShowFrame "Mostrar Menu Inferior" 0 "Mostra a barra de menu inferior."
-# ====== TODO To be translated ======
-menuText U TreeOptSmallFont "Use Custom Font" 0 "Use font_Small for Gamelist."
+menuText U TreeOptSmallFont "Use fonte pessoal" 0 "Use fonte pequena para lista de jogos."
 menuText U TreeOptSortBest "Ordenar melhores jogos" 0 "Ordena melhores jogos por ELO."
 menuText U TreeHelp "Ajuda" 0
 menuText U TreeHelpTree "Ajuda para rvore" 0
 menuText U TreeHelpIndex "ndice da Ajuda" 0
-translate U SaveCache {Salvar Cache}
+translate U SaveCache {Guardar Cache}
 translate U Training {Treinamento}
 translate U LockTree {Travamento}
 translate U TreeLocked {Travada} ;# ***
@@ -591,10 +594,8 @@ translate U RemoveFromMask {Remover da mscara}
 translate U AddThisMoveToMask {Adicionar este movimento  mscara}
 translate U SearchMask {Pesquisar na mscara}
 translate U DisplayMask {Mostrar mscara}
-# ====== TODO To be translated ======
-translate U MaskShowMarkers "Show Markers"
-# ====== TODO To be translated ======
-translate U MaskShowToolTips {Show Tooltips}
+translate U MaskShowMarkers "Mostrar marcadores"
+translate U MaskShowToolTips {Mostrar sugestes}
 translate U Nag {Cdigo Nag}
 translate U Marker {Marcador}
 translate U Include {Incluir}
@@ -648,8 +649,7 @@ translate U FinderCtxBackup {Guardar}
 translate U FinderCtxCopy {Copiar}
 translate U FinderCtxMove {Mover}
 translate U FinderCtxDelete {Apagar}
-# ====== TODO To be translated ======
-translate U FinderCtxRename {Rename}
+translate U FinderCtxRename {Renomear}
 translate U FinderDirOpen {Abrir Pasta}
 
 # Player finder:
@@ -662,8 +662,7 @@ menuText U PListSortElo "Elo" 0
 menuText U PListSortGames "Jogos" 0
 menuText U PListSortOldest "Antigo" 0 ;# ***
 menuText U PListSortNewest "Recente" 0 ;# ***
-# ====== TODO To be translated ======
-menuText U PListSortCountry "Country" 0
+menuText U PListSortCountry "Pas" 0
 
 # Tournament finder:
 menuText U TmtFile "Arquivo" 0
@@ -690,8 +689,7 @@ menuText U GraphOptions "Opes" 0
 menuText U GraphOptionsWhite "Branco" 0
 menuText U GraphOptionsBlack "Preto" 0
 menuText U GraphOptionsDots "Mostrar Pontos" 0
-# ====== TODO To be translated ======
-menuText U GraphOptionsSpelling "Elo from Spelling File" 0
+menuText U GraphOptionsSpelling "Elo do ficheiro de nomes" 0
 menuText U GraphOptionsBar "Destacar Lance atual" 0
 menuText U GraphOptionsBoth "Ambos" 0
 menuText U GraphOptionsPInfo "Informao do Jogador" 0
@@ -726,8 +724,7 @@ translate U AnnotateBlundersOnly {Quando a jogada  um grande erro}
 translate U BlundersNotBest {Apenas grandes erros}
 translate U AnnotateTitle {Configurar Anotao}
 translate U AnnotateMissedMates {Quando h xequemate mais rpido}
-# ====== TODO To be translated ======
-translate U AnnotateEnd {At end of game}
+translate U AnnotateEnd {No final da partida}
 translate U BlundersThreshold {Limiar}
 translate U ScoreFormat {Formato da avaliao}
 translate U CutOff {No anotar:}
@@ -932,17 +929,11 @@ translate U GlistUndeleteAllGames {Recuperar todos os jogos no filtro}
 translate U GlistAlignL {Alinhar  esquerda}
 translate U GlistAlignR {Alinhar  direita}
 translate U GlistAlignC {Alinhar ao centro}
-# ====== TODO To be translated ======
-translate U GlistMoveFieldUp {Move up}
-# ====== TODO To be translated ======
-translate U GlistMoveFieldDown {Move down}
-# ====== TODO To be translated ======
-translate U GlistMoveFieldFirst {Move to first}
-# ====== TODO To be translated ======
-translate U GlistMoveFieldLast {Move to last}
-# ====== TODO To be translated ======
-translate U GlistMoveFieldN {Move to N}
-
+translate U GlistMoveFieldUp {Mover para cima}
+translate U GlistMoveFieldDown {Mover para baixo}
+translate U GlistMoveFieldFirst {Mover para o primeiro}
+translate U GlistMoveFieldLast {Mover para o ltimo}
+translate U GlistMoveFieldN {Mover para N}
 # Maintenance window:
 translate U DatabaseName {Nome da base de dados:}
 translate U TypeIcon {Icone de Tipo:}
@@ -981,11 +972,9 @@ translate U CompactDatabase {Compactar Base}
 translate U SortDatabase {Ordenar Base}
 translate U AddEloRatings {Adicionar Elo}
 translate U AutoloadGame {Carregar autom. o jogo n.}
-# ====== TODO To be translated ======
-translate U StripTags {Extra Tags}
+translate U StripTags {Etiquetas extra}
 translate U StripTag {Apagar etiqueta} ;# ***
-# ====== TODO To be translated ======
-translate U AddTag {Add Tag}
+translate U AddTag {Adicionar etiqueta}
 translate U CheckGames {Verificar jogos}
 translate U Cleaner {Limpador}
 translate U CleanerHelp {
@@ -1156,8 +1145,7 @@ translate U ClearGameDialog {Este jogo foi alterado.  Voc realmente quer continu
 translate U ExitUnsaved {As seguintes bases tm alteraes no gravadas. Se sair agora, essas alteraes sero perdidas.} ;# ***
 translate U ChangeTextDialog {Configurar a cor geral do texto obriga a recomear o Scid.}
 translate U ChangeDockDialog {Mudar ligao a hardware obriga a recomear o Scid.}
-# ====== TODO To be translated ======
-translate U FontSelectDialog "This is some sample text\nDouble click above to change font, then select 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
+translate U FontSelectDialog "Isto  um texto de exemplo\D um duplo clic acima da letra mudada, depois selecion 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
 translate U ExitNow {Sair agora?}
 
 # Import window:
@@ -1241,8 +1229,7 @@ translate U OprepTheoryTable {Tabela de Teoria}
 translate U OprepTableComment {Gerada a partir dos %u jogos com rating mais alto.}
 translate U OprepExtraMoves {Movimentos com nota extra na Tabela de Teoria}
 translate U OprepMaxTableGames {Qtde. Mxima de jogos na tabela de teoria}
-# ====== TODO To be translated ======
-translate U OprepMaxGames {Maximum games for statistics}
+translate U OprepMaxGames {Mximo de jogos para estatstica}
 translate U OprepViewHTML {Ver HTML} ;# ***
 translate U OprepViewLaTeX {Ver LaTeX} ;# ***
 
@@ -1307,8 +1294,7 @@ translate U NameEditSelect {Jogos para editar}
 translate U NameEditReplace {Substituir}
 translate U NameEditWith {com}
 translate U NameEditMatches {Confere: Pressione Ctrl+1 a Ctrl+9 para selecionar}
-# ====== TODO To be translated ======
-translate U MatchPattern {Match Pattern}
+translate U MatchPattern {Corresponder ao padro}
 
 # Classify window:
 translate U Classify {Classificar}
@@ -1348,8 +1334,7 @@ translate U ExportComments {Exportar comentarios?}
 translate U ExportVariations {Exportar variantes?}
 translate U IndentComments {Alinhar Comentarios?}
 translate U IndentVariations {Alinhar Variantes?}
-# ====== TODO To be translated ======
-translate U InsertNewlines {Insert newlines every 80 chars?}
+translate U InsertNewlines {Introduzir linha a cada 80 carateres?}
 translate U ExportColumnStyle {Estilo Coluna (um movimento por linha)?}
 translate U ExportSymbolStyle {Estilo de anotao simblica:}
 translate U ExportStripMarks {Apagar dos comentrios as marcas de casa/seta?} ;# ***
@@ -1378,11 +1363,9 @@ translate U CopyErrNotOpen {no est aberta}
 translate U LightSquares {Casas Brancas}
 translate U DarkSquares {Casas Pretas}
 translate U SelectedSquares {Casas selecionadas}
-# ====== TODO To be translated ======
-translate U SelectedOutline {Selected Box}
-# ====== TODO To be translated ======
-translate U SuggestedSquares {Suggested}
-translate U Grid {Grid}
+translate U SelectedOutline {Selecionar caixa}
+translate U SuggestedSquares {Sugerido}
+translate U Grid {Quadrcula}
 translate U Previous {Escolhas}
 translate U WhitePieces {Peas Brancas}
 translate U BlackPieces {Peas Pretas}
@@ -1459,8 +1442,7 @@ translate U moveblunderthreshold {movimento  erro se perder mais de}
 translate U limitanalysis {limitar tempo de anlise do programa}
 translate U seconds {segundos}
 translate U Abort {Abortar}
-# ====== TODO To be translated ======
-translate U Quit {Quit}
+translate U Quit {Sair}
 translate U Resume {Retomar}
 translate U Restart {Recomear}
 translate U OutOfOpening {Fora da abertura}
@@ -1513,8 +1495,7 @@ translate U WinWonGame {Jogar at ao mate}
 translate U Lines {Linhas}
 translate U ConfigureUCIengine {Configurar programa UCI}
 translate U SpecificOpening {Escolher abertura}
-# ====== TODO To be translated ======
-translate U ImportECO {Import ECO}
+translate U ImportECO {Importar ECO}
 translate U StartNewGame {Iniciar novo jogo}
 translate U FixedLevel {Nvel fixo}
 translate U Opening {Abertura}
