@@ -22,7 +22,7 @@ menuText S FileClose "Cerrar" 0 {Cierra la base de datos Scid activa}
 menuText S FileFinder "Visor..." 0 {Abre la ventana del visor de archivos}
 menuText S FileSavePgn "Grabar PGN" 0 {Graba la partida a un fichero PGN}
 menuText S FileOpenBaseAsTree "Abrir base como rbol" 0   {Abrir una base y usarla en la ventana de rbol (Tree)}
-menuText S FileOpenRecentBaseAsTree "Abrir base reciente como rbol" 0   {Abre una base reciente y la usa en ventana de rbol (Tree)} 
+menuText S FileOpenRecentBaseAsTree "Abrir base reciente como rbol" 0   {Abre una base reciente y la usa en ventana de rbol (Tree)}
 menuText S FileBookmarks "Partidas favoritas" 0 {Seleccionar partidas favoritas (Ctrl+B)}
 menuText S FileBookmarksAdd "Aadir" 0 {Seala la partida y posicin actual de la base de datos}
 menuText S FileBookmarksFile "Archivar" 8 {Archiva un marcador para la partida y posicin actual}
@@ -41,8 +41,7 @@ menuText S EditAdd "Aadir variacin" 0 \
   {Aade una variacin a este movimiento en la partida}
 menuText S EditPasteVar "Pegar Variacin" 0
 menuText S EditDelete "Borrar variacin" 0 {Borra variacin para este movimiento}
-# ====== TODO To be translated ======
-menuText S EditDeleteComment "Delete Comment" 0
+menuText S EditDeleteComment "Borrar comentario" 0
 menuText S EditFirst "Convertir en primera variacin" 0 \
   {Hace que una variacin sea la primera en la lista}
 menuText S EditMain "Variacin a lnea principal" 0 \
@@ -80,7 +79,7 @@ menuText S EditSetup "Editar posicin..." 26 \
 menuText S EditCopyBoard "Copiar posicin" 8 \
   {Copia el tablero actual en notacin FEN a la seleccin de texto (clipboard)}
 # Benigno
-menuText S EditCopyPGN "Copiar partida PGN" 0 {} 
+menuText S EditCopyPGN "Copiar partida PGN" 0 {}
 
 # Benigno
 menuText S EditPasteBoard "Pegar posicin" 6 \
@@ -182,8 +181,7 @@ menuText S ToolsMaint "Mantenimiento" 0 \
   {Herramientas de mantenimiento de la base de datos Scid}
 menuText S ToolsMaintWin "Mantenimiento" 0 \
   {Abre/cierra la ventana de mantenimiento de la base de datos Scid}
-# ====== TODO To be translated ======
-menuText S ToolsMaintExtra "Extra Tags" 0 {Extra Tags}
+menuText S ToolsMaintExtra "Etiquetas extra" 0 {Etiquetas extra}
 menuText S ToolsMaintCompact "Compactar base de datos..." 0 \
   {Compacta los archivos de la base de datos, quitando partidas borradas y nombres no usados}
 menuText S ToolsMaintClass "Clasificar partidas por ECO..." 24 \
@@ -204,7 +202,6 @@ menuText S ToolsMaintNameSite "Correccin de nombres de lugares" 11 \
   {Comprobacin ortogrfica de lugares usando el archivo de comprobacin ortogrfica}
 menuText S ToolsMaintNameRound "Correccin de nombre de rondas" 11 \
   {Comprobacin ortogrfica de rondas usando el archivo de comprobacin ortogrfica}
-# ====== TODO To be translated ======
 menuText S ToolsMaintFixBase "Reparar base corrupta" 0 {Intenta reparar una base corrupta}
 menuText S ToolsConnectHardware "Conectar hardware" 0 {Conectar  hardware externo}
 menuText S ToolsConnectHardwareConfigure "Configurar..." 0 {Configurar conexin a hardware externo}
@@ -224,7 +221,7 @@ menuText S ToolsExpCurrentPGN "Exportar Partida a PGN" 15 \
   {Escribe la partida actual en un archivo PGN}
 menuText S ToolsExpCurrentHTML "Exportar Partida a HTML" 15 \
   {Escribe la partida actual en un archivo HTML}
-menuText S ToolsExpCurrentHTMLJS "Exportar Partida a HTML y JavaScript" 15 {Escribir partida actual a un fichero HTML y JavaScript} 
+menuText S ToolsExpCurrentHTMLJS "Exportar Partida a HTML y JavaScript" 15 {Escribir partida actual a un fichero HTML y JavaScript}
 menuText S ToolsExpCurrentLaTeX "Exportar Partida a LaTeX" 33 \
   {Escribe la partida actual en un archivo LaTeX}
 menuText S ToolsExpFilter "Exportar todas las partidas filtradas" 1 \
@@ -233,12 +230,11 @@ menuText S ToolsExpFilterPGN "Exportar filtro a PGN" 17 \
   {Escribe todas las partidas filtradas en un archivo PGN}
 menuText S ToolsExpFilterHTML "Exportar filtro a HTML" 17 \
   {Escribe todas las partidas filtradas en un archivo HTML}
-menuText S ToolsExpFilterHTMLJS "Exportar filtro a HTML y JavaScript" 17 {Escribir todas las partidas filtradas a fichero HTML y JavaScript}  
+menuText S ToolsExpFilterHTMLJS "Exportar filtro a HTML y JavaScript" 17 {Escribir todas las partidas filtradas a fichero HTML y JavaScript}
 menuText S ToolsExpFilterLaTeX "Exportar filtro a LaTeX" 17 \
   {Escribe todas las partidas filtradas en un archivo LaTeX}
-# ====== TODO To be translated ======
-menuText S ToolsExpFilterEPD "Export Filter to EPD/FEN" 17 {Write all filtered games to an EPD File}
-menuText S ToolsExpFilterGames "Exportar Listado a Texto" 19 {Print a formatted Gamelist.}
+menuText S ToolsExpFilterEPD "Exportar filtro a EPD/FEN" 17 {Guarda todos los juegos filtrados en un archivo EPD}
+menuText S ToolsExpFilterGames "Exportar Listado a Texto" 19 {Imprime un listado del juego formateado.}
 menuText S ToolsImportOne "Importar partida PGN" 0 \
   {Importa una partida de un texto PGN}
 menuText S ToolsImportFile "Importar archivo de partidas PGN" 2 \
@@ -281,15 +277,12 @@ menuText S Options "Opciones" 0
 menuText S OptionsBoard "Tablero" 0 {Opciones sobre el aspecto del tablero}
 menuText S OptionsColour "Color de fondo" 0 {Color de fondo por defecto}
 menuText S OptionsBackColour "Fondo" 0 {Color del widget de texto predeterminado}
-# ====== TODO To be translated ======
-menuText S OptionsBackColourGlobal "Global" 0 {Global background color}
+menuText S OptionsBackColourGlobal "Global" 0 {Color de fondo global}
 menuText S OptionsMainLineColour "Flechas principales" 0 {Flechas principales}
 menuText S OptionsVarLineColour "Flechas de variacin" 0 {Flechas de variacin}
-# ====== TODO To be translated ======
-menuText S OptionsEngineLineColour "Engine Arrows" 0 {Engine arrows}
+menuText S OptionsEngineLineColour "Flechas del motor" 0 {Flechas del motor}
 menuText S OptionsRowColour "Filas" 0 {Color predeterminado de la columna de rbol/libro}
-# ====== TODO To be translated ======
-menuText S OptionsHighlightColour "Highlight" 0 {Default text highlight color}
+menuText S OptionsHighlightColour "Resaltado" 0 {Color por defecto del texto resaltado}
 menuText S OptionsSwitcherColour "Conmutador" 0 {Color del conmutador db predeterminado}
 menuText S OptionsProgressColour "Barra de progreso" 0 {Color predeterminado de la barra de progreso}
 menuText S OptionsScoreColour "Grfico de puntuacin" 0 {}
@@ -301,11 +294,11 @@ menuText S OptionsFontsRegular "Habitual" 0 {Cambia la fuente habitual}
 menuText S OptionsFontsMenu "Men" 0 {Cambia la fuente del men}
 menuText S OptionsFontsSmall "Pequea" 0 {Cambia la fuente pequea}
 menuText S OptionsFontsFixed "Fijada" 0 {Cambia la anchura fijada de la fuente}
+menuText S OptionsEvalbar "Barra de evaluacin" 0 {Opciones de la barra de evaluacin}
 menuText S OptionsGInfo "Informacin de la partida" 0 {Informacin de la partida}
 menuText S OptionsFics "FICS" 0
 menuText S OptionsFicsAuto "Autopromocin Reina" 0
-# ====== TODO To be translated ======
-menuText S OptionsFicsClk "Store Clock times" 0
+menuText S OptionsFicsClk "Guarda los tiempos del reloj" 0
 menuText S OptionsFicsColour "Color del texto" 0
 menuText S OptionsFicsSize "Tamao del Tablero" 0
 menuText S OptionsFicsButtons "Botones de usuario" 0
@@ -313,14 +306,22 @@ menuText S OptionsFicsCommands "Comandos iniciales" 0
 menuText S OptionsFicsNoRes "Sin resultados" 0
 menuText S OptionsFicsNoReq "Sin respuesta" 0
 menuText S OptionsFicsPremove "Permitir Pre-movimiento" 0
+menuText S OptionsEvalMain "Tablero principal" 0
+menuText S OptionsEvalBrowser "Navegadores de juego" 0
+menuText S OptionsEvalFics "Tableros Fics" 0
+menuText S OptionsEvalTime "Tiempo de evaluacin" 0 {Tiempo para el anlisis rpido}
+# ====== TODO To be translated ======
+menuText S OptionsEvalScale "Scale" 0 {Scorebar scale}
+# ====== TODO To be translated ======
+menuText S OptionsEvalTicks "Show ticks" 0
+menuText S OptionsEvalLog  "Evaluacin logartmica" 0
 menuText S OptionsLanguage "Lenguaje" 0 {Selecciona el lenguaje del men}
 menuText S OptionsMovesTranslatePieces "Traducir piezas" 0 {Traducir la primera letra de las piezas}
 menuText S OptionsMovesHighlightLastMove "Resalta ltima jugada" 0 {Resalta la ltima jugada}
 menuText S OptionsMovesHighlightLastMoveDisplay "Mostrar" 0 {Muestra la ltima jugada iluminada}
 menuText S OptionsMovesHighlightLastMoveWidth "Ancho" 0 {Espesor de la lnea}
 menuText S OptionsMovesHighlightLastMoveColor "Select Color" 0 {Color de lnea}
-# ====== TODO To be translated ======
-menuText S OptionsMovesColorSelected "Color Selected Square" 0 {Color move}
+menuText S OptionsMovesColorSelected "Color de la casilla seleccionada" 0 {Color del movimiento}
 menuText S OptionsMoves "Movimientos" 0 {Opciones de la entrada de movimientos}
 menuText S OptionsMovesAsk "Preguntar antes de reemplazar movimientos" 0 \
   {Pregunta antes de sobreescribir cualquier movimiento existente}
@@ -330,10 +331,9 @@ menuText S OptionsMovesDelay "Retardo del Automovimiento" 1 \
   {Pone el tiempo de demora para el modo de automovimiento}
 menuText S OptionsMovesCoord "Entrada de movimientos coordinada" 0 \
   {Acepta entrada de movimientos en sistema "coordinado" ("g1f3")}
-# ====== TODO To be translated ======
-menuText S OptionsMovesSuggest "Show Suggested Moves" 0 {Turn on/off move suggestion}
+menuText S OptionsMovesSuggest "Mostrar movimientos sugeridos" 0 {Activa o desactiva la sugerencia de movimientos}
 menuText S OptionsShowVarPopup "Mostrar ventana de variaciones" 0 {Activa/desactivar la ventana de variaciones}
-menuText S OptionsMovesSpace "Aadir espacios detrs de nmero de jugada" 0 {Aadir espacios detrs del nmero de jugada}  
+menuText S OptionsMovesSpace "Aadir espacios detrs de nmero de jugada" 0 {Aadir espacios detrs del nmero de jugada}
 menuText S OptionsMovesKey "Teclado inteligente" 0 \
 {Activa/desactiva la funcin de autocompletado inteligente de movimientos con teclado}
 menuText S OptionsMovesShowVarArrows "Mostrar flechas para las variaciones" 0 \
@@ -373,7 +373,7 @@ menuText S OptionsInformant "Configurar valores de informacin" 0
 menuText S OptionsSave "Guardar opciones" 0 \
   "Guarda todas las opciones en el fichero $::optionsFile"
 
-menuText S OptionsSaveBases "Guardar bases por defecto" 0 
+menuText S OptionsSaveBases "Guardar bases por defecto" 0
 
 menuText S OptionsAutoSave "Autoguardar opciones al salir" 0 \
   {Guarda automticamente todas las opciones cuando se sale de Scid}
@@ -409,6 +409,7 @@ menuText S GInfoMenuBar "Barra de Mens"  0
 menuText S GInfoToolBar "Barra de Herramientas"  0
 menuText S GInfoButtonBar "Botn de Barra"  0
 menuText S GInfoStatusBar "Barra de Estado"  0
+menuText S GInfoEvalBar "Barra de evaluacin" 0
 
 translate S FlipBoard {Girar el tablero}
 translate S RaiseWindows {Aumentar ventanas}
@@ -513,8 +514,7 @@ translate S readonly {slo lectura}
 translate S altered {alterado}
 translate S tagsDescript {Etiquetas adicionales (p.e.: Annotator "Anand")}
 translate S prevTags {Usar el anterior}
-# ====== TODO To be translated ======
-translate S value {Value}
+translate S value {Valor}
 
 # Standard error messages:
 translate S ErrNotOpen {Esta base de datos no est abierta.}
@@ -626,10 +626,8 @@ menuText S TreeOptAutosave "Autoguardar archivo cach" 0 \
 menuText S TreeOptAutomask "Carga automtica de mscara" 0 "Carga automtica de mscara con un arbol abierto."
 menuText S TreeOptCacheSize "Tamao de cach" 0 {Fija el tamao del cach}
 menuText S TreeOptShowBar "Mostrar barra de progreso" 0 "Mostrar barra de progreso del rbol"
-# ====== TODO To be translated ======
-menuText S TreeOptShowFrame "Show Button Bar" 0 "Show tree button bar."
-# ====== TODO To be translated ======
-menuText S TreeOptSmallFont "Use Custom Font" 0 "Use font_Small for Gamelist."
+menuText S TreeOptShowFrame "Mostrar barra de botones" 0 "Muestra la barra de botones."
+menuText S TreeOptSmallFont "Usar fuente personalizada" 0 "Usa font_Small para el listado del juego."
 menuText S TreeOptSortBest "Ordenar mejores partidas" 0 "Ordenar mejores partidas por ELO."
 menuText S TreeHelp "Ayuda" 1
 menuText S TreeHelpTree "Ayuda del rbol" 4
@@ -653,10 +651,8 @@ translate S RemoveFromMask {Elimina desde la mscara}
 translate S AddThisMoveToMask {Aadir este movimiento a la mscara}
 translate S SearchMask {Buscar en mscara}
 translate S DisplayMask {Mostrar mscara}
-# ====== TODO To be translated ======
-translate S MaskShowMarkers "Show Markers"
-# ====== TODO To be translated ======
-translate S MaskShowToolTips {Show Tooltips}
+translate S MaskShowMarkers "Mostrar marcadores"
+translate S MaskShowToolTips {Mostrar ayudas}
 translate S Nag {Cdigo de regao}
 translate S Marker {Marcador}
 translate S Include {Incluir}
@@ -679,8 +675,7 @@ translate S CommentMove {Comentar movimiento}
 translate S CommentPosition {Comentar posicin}
 translate S AddMoveToMaskFirst {Aadir primero el movimiento a la mscara}
 translate S OpenAMaskFileFirst {Abrir primero un fichero de mscara}
-# ====== TODO To be translated ======
-translate S positions {positions}
+translate S positions {posiciones}
 translate S Moves {Jugadas}
 
 # Finder window:
@@ -711,10 +706,8 @@ translate S FinderCtxBackup {Copia de seguridad (Backup)}
 translate S FinderCtxCopy {Copia}
 translate S FinderCtxMove {Jugada}
 translate S FinderCtxDelete {Borrar}
-# ====== TODO To be translated ======
-translate S FinderCtxRename {Rename}
-# ====== TODO To be translated ======
-translate S FinderDirOpen {Open Directory}
+translate S FinderCtxRename {Renombra}
+translate S FinderDirOpen {Abrir directorio}
 
 # Player finder:
 menuText S PListFile "Archivo" 0
@@ -726,8 +719,7 @@ menuText S PListSortElo "Elo" 0
 menuText S PListSortGames "Partidas" 0
 menuText S PListSortOldest "Ms antiguo" 10
 menuText S PListSortNewest "Ms nuevo" 4
-# ====== TODO To be translated ======
-menuText S PListSortCountry "Country" 0
+menuText S PListSortCountry "Pas" 0
 
 # Tournament finder:
 menuText S TmtFile "Archivo" 0
@@ -790,8 +782,7 @@ translate S AnnotateBlundersOnly {Cuando el movimiento es un disparate}
 translate S BlundersNotBest {Fallo/No Mejor}
 translate S AnnotateTitle {Configurar anotacin}
 translate S AnnotateMissedMates {Mates omitidos/ms cortos}
-# ====== TODO To be translated ======
-translate S AnnotateEnd {At end of game}
+translate S AnnotateEnd {Al final del juego}
 translate S BlundersThreshold {(Umbral)}
 translate S ScoreFormat {Formato de puntuacin}
 translate S CutOff {Corte}
@@ -810,12 +801,9 @@ translate S Informant+/- {Blancas tienen ventaja}
 translate S Informant+- {Blancas tienen una ventaja decisiva}
 translate S Informant++- {La partida es considerada ganada}
 translate S Book {Libro}
-# ====== TODO To be translated ======
-translate S OtherBook {Other Moves}
-# ====== TODO To be translated ======
-translate S Alphabetical {Alphabetical}
-# ====== TODO To be translated ======
-translate S TwoBooks {Two Books}
+translate S OtherBook {Otros movimientos}
+translate S Alphabetical {Alfabtico}
+translate S TwoBooks {Dos libros}
 
 # Analysis Engine open dialog:
 translate S EngineList {Lista de motores de anlisis}
@@ -956,7 +944,7 @@ translate S BlunderFlag {Error}
 translate S UserFlag {Usuario}
 translate S PgnContains {PGN contiene texto}
 translate S PreComment {Comentario previo al juego}
-translate S PostComment {Fin del comentario} 
+translate S PostComment {Fin del comentario}
 
 # Game list window:
 translate S GlistNumber {Nmero}
@@ -993,22 +981,17 @@ translate S GlistSort {Ordenar base de datos}
 translate S GlistRemoveThisGameFromFilter  {Oculta esta partida}
 translate S GlistRemoveGameAndAboveFromFilter  {Oculta partidas por encima}
 translate S GlistRemoveGameAndBelowFromFilter  {Oculta partidas por debajo}
-translate S GlistDeleteGame {Elimina/Recupera esta partida de la base} 
-translate S GlistDeleteAllGames {Elimina todas las partidas de la base que aparecen en el filtro} 
-translate S GlistUndeleteAllGames {Recupera todas las partidas borradas de la base que aparecen en el filtro} 
+translate S GlistDeleteGame {Elimina/Recupera esta partida de la base}
+translate S GlistDeleteAllGames {Elimina todas las partidas de la base que aparecen en el filtro}
+translate S GlistUndeleteAllGames {Recupera todas las partidas borradas de la base que aparecen en el filtro}
 translate S GlistAlignL {Alinear a la izquierda}
 translate S GlistAlignR {Alinear a la derecha}
 translate S GlistAlignC {Alinear al centro}
-# ====== TODO To be translated ======
-translate S GlistMoveFieldUp {Move up}
-# ====== TODO To be translated ======
-translate S GlistMoveFieldDown {Move down}
-# ====== TODO To be translated ======
-translate S GlistMoveFieldFirst {Move to first}
-# ====== TODO To be translated ======
-translate S GlistMoveFieldLast {Move to last}
-# ====== TODO To be translated ======
-translate S GlistMoveFieldN {Move to N}
+translate S GlistMoveFieldUp {Mover arriba}
+translate S GlistMoveFieldDown {Mover abajo}
+translate S GlistMoveFieldFirst {Mover al principio}
+translate S GlistMoveFieldLast {Mover al final}
+translate S GlistMoveFieldN {Mover a N}
 
 # Maintenance window:
 translate S DatabaseName {Nombre de la base:}
@@ -1048,11 +1031,9 @@ translate S CompactDatabase {Compactar base de datos}
 translate S SortDatabase {Ordenar base de datos}
 translate S AddEloRatings {Aadir clasificacin Elo}
 translate S AutoloadGame {Autocargar partida}
-# ====== TODO To be translated ======
-translate S StripTags {Extra Tags}
+translate S StripTags {Etiquetas extra}
 translate S StripTag {Quitar etiquetas}
-# ====== TODO To be translated ======
-translate S AddTag {Add Tag}
+translate S AddTag {Aadir etiqueta}
 translate S CheckGames {Revisar partidas}
 translate S Cleaner {MultiHerramienta}
 translate S CleanerHelp {
@@ -1221,14 +1202,10 @@ Realmente quieres hacer que esta base de datos sea de slo lectura?}
 translate S ExitDialog {Realmente quieres salir de Scid?}
 translate S ClearGameDialog {Esta partida ha sido alterada.\nDesea guardarla?}
 translate S ExitUnsaved {La siguiente base de datos tiene cambios en partidas no guardadas. Si sales ahora se perdern estos cambios.}
-# ====== TODO To be translated ======
-translate S ChangeTextDialog {Enabling text colour globally requires restart.}
-# ====== TODO To be translated ======
-translate S ChangeDockDialog {Changing Docking requires a restart.}
-# ====== TODO To be translated ======
-translate S FontSelectDialog "This is some sample text\nDouble click above to change font, then select 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
-# ====== TODO To be translated ======
-translate S ExitNow {Exit now ?}
+translate S ChangeTextDialog {Activar el color del texto globalmente requiere reiniciar.}
+translate S ChangeDockDialog {Cambiar el acoplado requiere reiniciar.}
+translate S FontSelectDialog "Ejemplo de texto\nHaz doble clic arriva para cambiar la fuente, y selecciona 'ok'\nAaBbCcDdEeFfGgHhIiJjKkLlMm 0123456789. +=-"
+translate S ExitNow {Salir ahora?}
 
 # Import window:
 translate S PasteCurrentGame {Pegar partida actual}
@@ -1313,8 +1290,7 @@ translate S OprepTheoryTable {Tabla Terica}
 translate S OprepTableComment {Generado a partir de las %u partidas con mejor Elo.}
 translate S OprepExtraMoves {Anotacin extra de movimientos en la tabla terica}
 translate S OprepMaxTableGames {Mximas partidas en la tabla terica}
-# ====== TODO To be translated ======
-translate S OprepMaxGames {Maximum games for statistics}
+translate S OprepMaxGames {Nmero mximo de juegos para estadsticas}
 translate S OprepViewHTML {Ver HTML}
 translate S OprepViewLaTeX {Ver LaTeX}
 
@@ -1379,8 +1355,7 @@ translate S NameEditSelect {Partidas a editar}
 translate S NameEditReplace {Reemplazar}
 translate S NameEditWith {Con}
 translate S NameEditMatches {Partidas: Presionar Ctrl+1 a Ctrl+9 para seleccionarla}
-# ====== TODO To be translated ======
-translate S MatchPattern {Match Pattern}
+translate S MatchPattern {Patrn de coincidencia}
 
 # Classify window:
 translate S Classify {Clasificar}
@@ -1420,8 +1395,7 @@ translate S ExportComments {Exportar comentarios?}
 translate S ExportVariations {Exportar variaciones?}
 translate S IndentComments {Sangrar comentarios?}
 translate S IndentVariations {Sangrar variaciones?}
-# ====== TODO To be translated ======
-translate S InsertNewlines {Insert newlines every 80 chars?}
+translate S InsertNewlines {Insertar saltos de lnea cada 80 caracteres?}
 translate S ExportColumnStyle {Estilo de columna (un movimiento por lnea)?}
 translate S ExportSymbolStyle {Estilo de anotacin simblico:}
 translate S ExportStripMarks {Quitar marca de cdigos de casilla/flecha de los comentarios?}
@@ -1450,10 +1424,8 @@ translate S CopyErrNotOpen {no est abierta}
 translate S LightSquares {Casillas claras}
 translate S DarkSquares {Casillas oscuras}
 translate S SelectedSquares {Casillas seleccionadas}
-# ====== TODO To be translated ======
-translate S SelectedOutline {Selected Box}
-# ====== TODO To be translated ======
-translate S SuggestedSquares {Suggested}
+translate S SelectedOutline {Caja seleccionada}
+translate S SuggestedSquares {Sugeridas}
 translate S Grid {Cuadrcula}
 translate S Previous {Eleccin}
 translate S WhitePieces {Piezas blancas}
@@ -1462,8 +1434,7 @@ translate S WhiteBorder {Borde blancas}
 translate S BlackBorder {Borde negras}
 translate S ArrowMain   {Flecha lnea principal}
 translate S ArrowVar    {Flechas de variaciones}
-# ====== TODO To be translated ======
-translate S ShowArrows  {Show Arrows}
+translate S ShowArrows  {Mostrar flechas}
 
 # Novelty window:
 translate S FindNovelty {Encontrar novedad}
@@ -1534,8 +1505,7 @@ translate S moveblunderthreshold {El movimiento es una metedura de pata si la pr
 translate S limitanalysis {Tiempo lmite para anlisis del motor}
 translate S seconds {segundos}
 translate S Abort {Abortar}
-# ====== TODO To be translated ======
-translate S Quit {Quit}
+translate S Quit {Salir}
 translate S Resume {Reanudar}
 translate S Restart {Reiniciar}
 translate S OutOfOpening {Fuera de apertura}
@@ -1588,25 +1558,20 @@ translate S WinWonGame {Gana la partida ganada}
 translate S Lines {Lneas}
 translate S ConfigureUCIengine {Configurar motor}
 translate S SpecificOpening {Apertura especfica}
-# ====== TODO To be translated ======
-translate S ImportECO {Import ECO}
+translate S ImportECO {Importar ECO}
 translate S StartNewGame {Empezar partida nueva}
 translate S FixedLevel {Nivel fijado}
 translate S Opening {Abriendo}
 translate S RandomLevel {Nivel aleatorio}
 translate S StartFromCurrentPosition {Empezar desde la posicin actual}
 translate S FixedDepth {Profundidad fija}
-translate S Nodes {Nodos} 
+translate S Nodes {Nodos}
 translate S Depth {Profundidad}
-translate S Time {Tiempo} 
-# ====== TODO To be translated ======
+translate S Time {Tiempo}
 translate S Auto {Auto}
-# ====== TODO To be translated ======
-translate S Score {Score}
-# ====== TODO To be translated ======
-translate S {Score Combo} {Score Combo}
-# ====== TODO To be translated ======
-translate S {Time Combo} {Time Combo}
+translate S Score {Puntuacin}
+translate S {Score Combo} {Selector de puntuacin}
+translate S {Time Combo} {Selector de tiempo}
 translate S SecondsPerMove {Segundos por movimiento}
 translate S DepthPerMove {Profundidad por movimiento}
 translate S MoveControl {Movimiento del control}
@@ -1708,8 +1673,7 @@ translate S FICSTimeseal {Timeseal}
 translate S FICSTimesealPort {Puerto Timeseal}
 translate S FICSSilence {Silencio}
 translate S FICSOffers {Ofertas}
-# ====== TODO To be translated ======
-translate S FICSMakeOffer {Make Offer}
+translate S FICSMakeOffer {Hacer oferta}
 translate S FICSGames {Partidas}
 translate S FICSFindOpponent {Buscar oponente}
 translate S FICSTakeback {Retrocede}
@@ -1839,22 +1803,14 @@ translate S UriRejected	{Los siguientes archivos fueron rechazados:}
 translate S UriRejectedDetail {Slo pueden manejarse los tipos de archivo listados:}
 translate S EmptyUriList {Descartar. Contenido est vaco.}
 translate S SelectionOwnerDidntRespond {Tiempo excedido durante la operacin: el propietario de la seleccin no respondi.}
-# ====== TODO To be translated ======
-translate S PasteAnal {Paste Analysis}
-# ====== TODO To be translated ======
-translate S SortOpcodes {Sort Opcodes}
-# ====== TODO To be translated ======
-translate S AddPosition {Add Position}
-# ====== TODO To be translated ======
-translate S FindPos {Find Deepest Game Position}
-# ====== TODO To be translated ======
-translate S AnalPosition {Analyze Positions}
-# ====== TODO To be translated ======
-translate S StripOpcodes {Strip Opcodes}
-# ====== TODO To be translated ======
-translate S NoMoves {No moves from this position}
-# ====== TODO To be translated ======
-translate S CountBestMoves {Count Best Moves}
+translate S PasteAnal {Pegar anlisis}
+translate S SortOpcodes {Ordenar cdigos de operacin}
+translate S AddPosition {Aadir posicin}
+translate S FindPos {Encuentra la posicin de juego ms profunda}
+translate S AnalPosition {Analizar posiciones}
+translate S StripOpcodes {Separa cdigos de operacin}
+translate S NoMoves {No hay movimientos desde esta posicin}
+translate S CountBestMoves {Contar los mejores movimientos}
 
 }
 # end of spanish.tcl
